%||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||
% PRECIPITACION_MM5 permite determinar la variacion temporal 
% de la precipitacion en un elemento del espacio a escala diaria.
% _________________________________________________________________________
% Se le debe ingresar 10 parametros:
% 1. Nombre del Archivo Binario (NombreArchivo.bin)
% 2. Coordenada Geografica Latitud Norte (N)
% 3. Coordenada Geografica Latitud Sur (S)
% 4. Coordenada Geografica Longitud Oeste (W)
% 5. Coordenada Geografica Longitud Este (E)
% 6. El numero de filas que posea el archivo binario (MM5rows)
% 7. El numero de columnas que posea el archivo binario (MM5cols)
% 8. El numero de horas a transformar en dias (nrohoras)
% 9. El espaciamiento para la interpolacion (Esp)
% 10. La opcion de interpolacion: 'linear', 'nearest', 'cubic', 'spline'. (OpcionInterpolacion) 

clear

%%%%%%% DEFINICION DE VARIABLES
NombreArchivo = 'camigo.bin';
N = 35.4947;
S = 36.5856;
E = 74.6099;
W = 75.9589;
MM5cols = 11;
MM5rows = 11;
nrohoras = 100; %3960 
Esp = 10;
OpcionInterpolacion = 'linear';
% _________________________________________________________________________

%%%%%%% UNION DE INFORMACION HORARIA A ESCALA DIARIA
fi = fopen(NombreArchivo,'rb'); 
nrodias = round(nrohoras/24);
DatosDiarios = zeros(MM5cols,MM5rows,nrodias);
t = 0;
while t < nrodias 
    for i = (24*t+1):24*(t+1)
        DatosHorarios( :,:,i ) = fread( fi,[ MM5cols,MM5rows ],'float' );  
        DatosDiarios( :,:,t+1 ) = DatosDiarios( :,:,t+1 ) + DatosHorarios( :,:,i );
    end
    t = t+1;
end

%%%%%%%%%%%%%%%
titulo = ( ' Fecha = 12-Abr-2002, Hora = 13:00 ' ); 
pcolor( DatosHorarios( :,:,1 )), title(titulo), shading flat, colorbar;
%%%%%%%%%%%%%%%%
% _________________________________________________________________________


%%%%%%% CREACION DEL FORMATO MATRIZ A INTERPOLAR
MM5_E = 0:Esp:Esp*( MM5cols-1 );
MM5_S = 0:Esp:Esp*(MM5rows-1);    
Aux1 = 1:1:Esp*( MM5cols-1 );
Aux2 = 1:1:Esp*( MM5rows-1 );
[ M1, M2 ] = meshgrid( Aux1, Aux2 );
MatrizAux_2 = zeros( Esp*( MM5rows-1 ), Esp*( MM5cols-1 ), nrodias);
% _________________________________________________________________________

%%%%%%% INTERPOLACION DE LA MATRIZ CON INFORMACION DIARIA
for i = 1:nrodias
    MatrizAux_1 = DatosDiarios( :,:,i );      
    MatrizAux_1 = MatrizAux_1'; %Para voltear la matriz
    DatosInterpol = interp2( MM5_E, MM5_S, MatrizAux_1, M1, M2, OpcionInterpolacion );
    MatrizAux_2( :,:,i ) = DatosInterpol;
end
% _________________________________________________________________________

%%%%%%%%%%%%%%%%
figure(2)
titulo2 = strcat(' Columnas =  ', num2str( MM5rows-1 ),', Filas =  ', num2str( MM5cols-1 ),', Fecha = 13-Abr-2002 ' ); 
pcolor( DatosDiarios( :,:,1 )), shading flat, title(titulo2),colorbar;
figure(3)
titulo3 = strcat(' Columnas =  ', num2str(Esp*( MM5cols-1 )),', Filas =  ', num2str(Esp*( MM5rows-1 )), ...
', Fecha = 13-Abr-2002 , Opcion Interpolacion : ', OpcionInterpolacion ); 
pcolor( MatrizAux_2( :,:,1 )), shading flat, title(titulo3),colorbar;
pause(2);
%%%%%%%%%%%%%%%%%

% RESOLUCION DE ELEMENTOS EN GRADOS
    ncols = Esp*( MM5cols-1 );
    nrows = Esp*( MM5rows-1 );
    ResLon = abs(W - E)/ncols;
    ResLat = abs(S - N)/nrows;
% _________________________________________________________________________
   
% GUARDADO DE LA INFORMACION
save( 'ArchivoResultados', 'nrodias', 'Esp' ,'N', 'E', 'S', 'W' , 'MatrizAux_2', 'ResLon', 'ResLat', 'nrows', 'ncols');
    
disp(sprintf('Los registros Resultados se han grabado en :%s.', 'ArchivoResultados'));
% _________________________________________________________________________

clear
